@@ -14,9 +14,9 @@
            "want pretty printing", 
            "望麗出力"
        ]
-       >>> target_dict = {'order': {'en':'pretty print', 'ja':'綺麗に出力せよ'}}
+       >>> target_dict = {'order': {'en':'print prettily', 'ja':'綺麗に出力せよ'}}
        >>> print target_dict  # what a hell again
-       {'order': {'en': 'pretty print', 'ja': '\\xe7\\xb6\\xba\\xe9\\xba\\x97\\xe3\\x81\\xab\\xe5\\x87\\xba\\xe5\\x8a\\x9b\\xe3\\x81\\x9b\\xe3\\x82\\x88'}}
+       {'order': {'en': 'print prettily', 'ja': '\\xe7\\xb6\\xba\\xe9\\xba\\x97\\xe3\\x81\\xab\\xe5\\x87\\xba\\xe5\\x8a\\x9b\\xe3\\x81\\x9b\\xe3\\x82\\x88'}}
        >>> pp(target_dict)  # pp again
        {
            "order": {
@@ -27,7 +27,7 @@
 """
 
 __author__  = "Matsumoto Taichi"
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __license__ = "MIT License"
 
 from prettyprint import *
